@@ -3,7 +3,7 @@
 from pyatcommand import AtClient, AtTimeout
 
 from .common import (
-    AcquisitionSummary,
+    NetInfo,
     BeamType,
     DataFormat,
     EventNotification,
@@ -25,7 +25,7 @@ from .common import (
 from .location import GnssFixQuality, GnssFixType, GnssLocation, GnssSatelliteInfo
 from .message import IotNanoMessage, MoMessage, MtMessage
 from .modem import SatelliteModem
-from .utils import get_model, load_modem_class, clone_and_load_modem_classes
+from .loader import load_modem_class, clone_and_load_modem_classes
 
 __all__ = [
     'SatelliteModem',
@@ -43,7 +43,7 @@ __all__ = [
     'AtClient',
     'AtTimeout',
     'SignalQuality',
-    'AcquisitionSummary',
+    'NetInfo',
     'DataFormat',
     'EventNotification',
     'WakeupInterval',
@@ -56,7 +56,6 @@ __all__ = [
     'GnssFixQuality',
     'GnssSatelliteInfo',
     'OperatingMode',
-    'get_model',
     'load_modem_class',
     'clone_and_load_modem_classes',
 ]
