@@ -19,6 +19,7 @@ from .common import (
     PowerMode,
     WakeupInterval,
     GnssMode,
+    EventNotification,
 )
 from .location import GnssLocation
 from .message import MoMessage, MtMessage
@@ -63,6 +64,29 @@ class SatelliteModem(AtClient, ABC):
         """Get the modem model."""
         return self._model.name
     
+    def get_model(self) -> ModemModel:
+        """Check the model of the connected modem."""
+        model = self._model
+        mfr_res = self.send_command('ATI')
+        if mfr_res.ok and mfr_res.info:
+            if 'ORBCOMM' in mfr_res.info.upper():
+                model_res = self.send_command('ATI4')
+                if model_res.ok and model_res.info:
+                    if 'ST2' in model_res.info:
+                        proto_res = self.send_command('ATI5')
+                        if proto_res.ok and proto_res.info:
+                            if proto_res.info == '8':
+                                model = ModemModel.ST2_IDP
+                            elif proto_res.info == '10':
+                                model = ModemModel.ST2_OGX
+                            else:
+                                raise ValueError('Unsupported protocol value')
+            elif 'QUECTEL' in mfr_res.info.upper():
+                model = ModemModel.CC200A
+        if model != self._model:
+            _log.warning('Detected %s but expected %s', model.name, self.model)
+        return model
+        
     @property
     def firmware_version(self) -> str:
         """Get the modem firmware version."""
@@ -83,13 +107,20 @@ class SatelliteModem(AtClient, ABC):
             return resp.info
         return ''
     
+    def initialize(self, **kwargs) -> bool:
+        """Initialize settings for the modem.
+        
+        Settings for event notifications/monitoring and URC notifications.
+        """
+        return True
+    
     # @abstractmethod
     def get_network_state(self) -> NetworkState:
         """Get the current network state."""
         raise NotImplementedError('Implement in model-specific subclass')
     
     # @abstractmethod
-    def get_acquisition_summary(self):
+    def get_netinfo(self):
         """Get details of the acquisition process."""
         raise NotImplementedError('Implement in model-specific subclass')
     
@@ -105,7 +136,7 @@ class SatelliteModem(AtClient, ABC):
     
     def is_transmit_allowed(self) -> bool:
         """Check if message transmission is allowed."""
-        return self.get_network_state().is_connected()
+        return self.get_network_state().is_registered()
     
     def is_blocked(self) -> bool:
         """Check if line of sight is blocked."""
@@ -159,6 +190,15 @@ class SatelliteModem(AtClient, ABC):
         """
         raise NotImplementedError('Implement in model-specific subclass')
     
+    def clear_mo_message_queue(self) -> bool:
+        """Iterate the modem Tx queue to remove completed messages."""
+        tx_queue = self.get_mo_message_queue()
+        success = True
+        for msg in tx_queue:
+            if not self.mo_message_delete(msg.id):                              # type: ignore
+                success = False
+        return success
+    
     def mo_message_delete(self, message_id: Union[str, int]) -> bool:
         """Remove a completed mobile-originated message from the Tx queue.
         
@@ -183,6 +223,15 @@ class SatelliteModem(AtClient, ABC):
         """
         raise NotImplementedError('Implement in model-specific subclass')
     
+    def clear_mt_message_queue(self) -> bool:
+        """Iterate the modem Rx queue to remove completed messages."""
+        rx_queue = self.get_mt_message_queue()
+        success = True
+        for msg in rx_queue:
+            if not self.mt_message_delete(msg.id):                              # type: ignore
+                success = False
+        return success
+    
     # @abstractmethod
     def mt_message_recv(self, message: MtMessage, **kwargs) -> Union[MtMessage, None]:
         """Retrieve the specified message (by name) from the Rx queue.
@@ -217,7 +266,7 @@ class SatelliteModem(AtClient, ABC):
             The number of bytes sent if no callback is specified otherwise None.
         """
         self.data_mode = True
-        success = xmodem_bytes_handler(self._serial, 'send', data)   # pyright: ignore
+        success = xmodem_bytes_handler(self._serial, 'send', data)              # type: ignore
         self.data_mode = False
         callback = kwargs.get('callback')
         if callable(callback):
@@ -235,7 +284,7 @@ class SatelliteModem(AtClient, ABC):
             If `callback` is not specified returns the bytes, otherwise None. 
         """
         self.data_mode = True
-        data: bytes = xmodem_bytes_handler(self._serial, 'recv', None)   # pyright: ignore
+        data: bytes = xmodem_bytes_handler(self._serial, 'recv', None)          # type: ignore
         self.data_mode = False
         data = data.rstrip(b'\x1a') or b''
         callback = kwargs.get('callback')
@@ -366,7 +415,7 @@ class SatelliteModem(AtClient, ABC):
         if resp.ok and resp.info:
             events_str = [e.strip() for e in resp.info.split(',')]
             for event in events_str:
-                events.append(tuple([int(v) for v in event.split('.')]))   # pyright: ignore
+                events.append(tuple([int(v) for v in event.split('.')]))        # type: ignore
         else:
             _log.warning('Unable to determine monitored trace events')
         return events
@@ -396,3 +445,11 @@ class SatelliteModem(AtClient, ABC):
         else:
             _log.warning('Unable to determine last error code')
             return 0
+    
+    def get_urc_event(self, urc: str) -> Union[EventNotification, None]:
+        """Parse a URC to derive an event notification."""
+        raise NotImplementedError('Implement in model-specific subclass')
+    
+    def report_debug(self, **kwargs):
+        """Log a debug report."""
+        raise NotImplementedError('Implement in model-specific subclass')
